import Taro, { Component } from '@tarojs/taro'
import { connect } from '@tarojs/redux'
import * as actions from '@actions/user'
import getUserPhone from '@utils/getUserPhone'
import './index.scss'
import { getHFiveDetail } from '@services/user'
import ready from '@utils/ready'
import { reportClient } from '@services/report'
const bgImg = require('@assets/helpgroup/bg.png')

@connect(state => state.user, { ...actions })

export default class Index extends Component {

  state = {
    avatarVisible: true,
    phoneVisible: false,
    webViewVisible: false,
    pageInfo: {}
  }
  componentWillMount() {

    ready.queue(() => {
      getHFiveDetail(this.$router.params.id).then(res => {
        this.setState({
          pageInfo: res
        })
      })
      const { userInfo: { person } } = this.props
      if (person.avatarurl) {
        // 头像手机号都有
        if (person.phone) {
          this.setState({
            avatarVisible: false,
            phoneVisible: false,
            webViewVisible: true,
          })
        } else {
          this.onAvatarSuccess();
        }
      } else {
        if (person.phone) {
          this.setState({
            phoneVisible: false,
          })
        }
      }
    })
  }

  // 授权头像成功
  onAvatarSuccess() {
    this.setState({
      avatarVisible: false,
      phoneVisible: true,
    })
    console.log("授权头像成功！")
  }
  // 授权用户信息
  getUserInfo() {
    const { dispatchUpdateUserInfo } = this.props
    const sessionKey = Taro.getStorageSync('sessionKey')
    Taro.showLoading()
    Taro.getUserInfo({
      lang: 'zh_CN',
      success: res => {
        const payload = Object.assign(res, { sessionKey })
        // 用户信息保存至服务器
        dispatchUpdateUserInfo(payload).then(res => {
          console.log('获取用户信息成功')
          this.onAvatarSuccess();
          Taro.hideLoading()
        })
      },
      fail: (err) => {
        Taro.hideLoading()
        console.error(err)

        Taro.showToast({
          title: '获取用户信息失败',
          icon: 'none'
        })
        return
      }
    })
  }
  // onShareAppMessage = () => {
  //   const {pageInfo } = this.state
  //   // const { agent: { nickname, personId, agentCode } } = this.state
  //   return {
  //     // title: `${nickname}邀请你成为经纪人`,
  //     path: `/pages/project/h5Page?id=${personId}&from=share&recommender=${personId}&agentCode=${agentCode}`,//分享地址
  //     imageUrl: pageInfo.shareImg
  //   }
  // }
  getPhoneNumber(e) {
    getUserPhone(e, (phoneNumber) => {
      if (!phoneNumber) {
        Taro.showToast({
          title: '获取手机号失败',
          icon: 'none'
        })
      } else {
        console.log('授权手机成功')
        this.setState({
          phoneVisible: false,
          webViewVisible: true,
        })
      }
    })
  }
  // 报备客户
  reportClient() {
    const {
      cardInfo: { id, projects = [] },
      userInfo: { person: { phone, tel } }
    } = this.props
    const buildingId = projects[0]
    const realPhone = phoneNumber || phone || tel
    const payload = {
      realtyConsultant: id, //报备人 置业顾问
      buildingId,
      phone: realPhone
    }
    const { cardInfo, userInfo: { person } } = this.props
    if (person.personId != cardInfo.id) {
      reportClient(payload).then(res => {
        this.hideModal()
        console.log('恭喜您绑定成功')
        // this.setState({ bound: true })
        // if (res !== 'bound') {
        //   Taro.showToast({
        //     title: '恭喜您绑定成功'
        //   })
        // }
      }).catch(err => {
        console.error(err)
        this.setState({ bound: true })

        // Taro.showToast({
        //   title: err.message || err,
        //   icon: 'none'
        // })
      })
    }
  }

  renderMaskBanner() {
    const { avatarVisible, phoneVisible, pageInfo } = this.state
    return (
      <View>
        <Image src={pageInfo.middleImg || bgImg} mode='widthFix' className='bg_img'></Image>
        <View className="middle-page">
          {avatarVisible &&
            <View className="content">
              <View className="title">授权头像，围观活动</View>
              <Image className="touxiang" src={require('@assets/default-avatar.png')}></Image>
              <View className="name">用户昵称</View>
              <Button className="btn" open-type="getUserInfo" lang="zh_CN" onGetUserInfo={this.getUserInfo}>好</Button>
            </View>
          }
          {phoneVisible &&
            <Button className="phone-btn" open-type="getPhoneNumber" lang="zh_CN" onGetphonenumber={this.getPhoneNumber}>点击授权查看详情</Button>
          }

        </View>
      </View>
    )
  }
  render() {
    const { pageInfo, webViewVisible } = this.state
    return (
      <Block>
        {this.renderMaskBanner()}
        {webViewVisible && <WebView src={pageInfo.h5Address + '?personid=xxx&h5id=xxx&xxxx'} />}
      </Block>
    )
  }
}
